@@ -3121,5 +3121,9 @@ def save():
 	with open('word_awl.json','w') as fw: 
 		fw.write(json.dumps([ w for w in word_awl]))
 
+def save_tsv():
+	with open('awl.tsv','w') as fw: 
+		[ fw.write(f"{w}\n") for w in word_awl]
+
 if __name__ == '__main__': 
-	save()
\ No newline at end of file
+	save_tsv()
\ No newline at end of file
