@@ -7,14 +7,11 @@ def run():
 	st.caption(hget(f"config:rid-{rid}:tid-{tid}","subtitle")) 
 
 	essay = st.text_area( "Input an essay", hget(f"config:rid-{rid}:tid-{tid}",  "input-default"), height=350)
-	if st.button("submit") : #essay != st.session_state.get(f'rid-{rid}:tid-{tid}:uid-{uid}:essay',"")
+	if st.button("submit") : 
 		st.session_state[f'rid-{rid}:tid-{tid}:uid-{uid}:essay'] = essay 
-		id = redis.r.xadd(xname, {"rid": rid, "tid": tid,"uid": uid, "essay_or_snts": essay, "submit": 1, 'uname': st.experimental_get_query_params().get('uname', [''])[0]})
-		if 'debug' in app_state: 
-			st.sidebar.write( f"essay submitted {id}" ) 
-			st.sidebar.write( redis.r.xrevrange(xname, count=1))
-
-		res = redis.r.blpop(f"gecdsk:{id}", timeout=app_state.get('timeout',5))
+		id = redis.r.xadd(xname, {"rid": rid, "tid": tid,"uid": uid, "essay_or_snts": essay, "submit": 1})
+		if 'debug' in app_state: st.sidebar.write( redis.r.xrevrange(xname, count=1))
+		res = redis.r.blpop(f"xdsk:{id}", timeout=app_state.get('timeout',5))
 		if 'debug' in app_state: st.sidebar.write(res)  
 		if res: st.metric("SCORE", round(float(json.loads(res[1]).get('info',{}).get("final_score",0)), 2) )
 
