@@ -17,13 +17,13 @@ def mkf_input(snts, docs, tokenizer, sntdic:dict={},diffmerge:bool=False):
 				for i, doc in enumerate(docs)]
 	return input #mkfs	= requests.post(f"http://172.17.0.1:7095/parser", data={"q":json.dumps(input).encode("utf-8")}).json()
 
-@app.get('/dsk/register_redis')
+@app.get('/dsk/register_redis', tags=["dsk"])
 def register_redis(rinfo:str='172.17.0.1:6379:0'):
 	''' to enable redis cache for snt parsing , 2022.6.30 '''
 	en.redis_xsntbytes = en.register_redis(rinfo, force=True)
 	return en.redis_xsntbytes
 
-@app.post('/dsk')
+@app.post('/dsk', tags=["dsk"])
 def post_dsk(arr:dict={'essay_or_snts':"She has ready. It are ok.", # arr from mq 
 				'formula':{ 
 				"ast":[9.9, 11.99, 15.3, 18.51, 25.32,				2,0.0882, 0.3241],
@@ -67,16 +67,13 @@ def post_dsk(arr:dict={'essay_or_snts':"She has ready. It are ok.", # arr from m
 		exc_type, exc_value, exc_traceback_obj = sys.exc_info()
 		traceback.print_tb(exc_traceback_obj)
 
-@app.get('/dsk')
+@app.get('/dsk', tags=["dsk"])
 def get_dsk(essay:str="She has ready. It are ok.", asdsk:bool=True, debug:bool= False, dskhost:str='172.17.0.1:7095'):
 	''' '''
 	return post_dsk({"essay_or_snts":essay}, asdsk, debug, dskhost)
 
-if __name__ == '__main__':
-	print (post_dsk())
-	uvicorn.run(app, host='0.0.0.0', port=80)
-
-def wrapper(essay_or_snts:str="She has ready. It are ok.", asdsk:bool=True, debug:bool= False, timeout:int=5, gechost:str='172.17.0.1:8180' , dskhost:str='172.17.0.1:7095'): 
+@app.get('/dsk/wrapper', tags=["dsk"])
+def dsk_wrapper(essay_or_snts:str="She has ready. It are ok.", asdsk:bool=True, timeout:int=5, gechost:str='gpu120.wrask.com:8180' , dskhost:str='gpu120.wrask.com:7095'): 
 	''' simple wrapper for debug only, 2022.6.5 '''
 	snts	= json.loads(essay_or_snts) if essay_or_snts.startswith("[") else en.sntbr(essay_or_snts)
 	sntdic	= requests.post(f"http://{gechost}/getgecs", params={"timeout":timeout}, json=snts).json ()
@@ -84,6 +81,13 @@ def wrapper(essay_or_snts:str="She has ready. It are ok.", asdsk:bool=True, debu
 	input	= mkf_input(snts, docs, spacy.nlp.tokenizer, sntdic)
 	return	requests.post(f"http://{dskhost}/parser", data={"q":json.dumps({"snts":input, "rid":"10"} if asdsk else input).encode("utf-8")}).json()
 
+@app.get('/dsk/mkf', tags=["dsk"])
+def dsk_mkf(essay_or_snts:str="She has ready. It are ok.", timeout:int=5, gechost:str='gpu120.wrask.com:8180' , dskhost:str='gpu120.wrask.com:7095'): 
+	return dsk_wrapper(essay_or_snts, asdsk=False, timeout=timeout, gechost=gechost, dskhost=dskhost)
+
+if __name__ == '__main__': #uvicorn.run(app, host='0.0.0.0', port=80)
+	print (dsk_wrapper("[\u8bd1\u6587]The 55-kilometre Hong Kong Zhuhai-Macau Bridge is an extraordinary engineering. It is the world's longest sea-crossing transportation system combining bridges and tunnels, which joins the three cities of Hong Kong Zhuhai and Macao, cutting the travelling time among them from 3 hours to 30 minutes. The reinforced concrete bridge with huge spans fully not only proves that China has the ability to complete the record-breaking mega-construction, but also will enhance the regional integration and boost the economic growth. It plays a crucial role in the overall plan to develop China’s Great Bay Area, which China intends to turn into one rivaling those of San Francisco, New York and Tokyo in terms of technological innovation and economic prosperity."))
+
 def topk_info(snts, docs,  topk, default_dims = {"internal_sim":0.2} ): 
 	''' info computing with topk snts, upon those long essay '''
 	from dsk import score, pingyu
